@@ -1,6 +1,7 @@
 // Predefined symbols and macros -*- C++ -*-
 
-// Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+// Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
+// 2006, 2007
 // Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
@@ -28,6 +29,11 @@
 // invalidate any other reasons why the executable file might be covered by
 // the GNU General Public License.
 
+/** @file c++config.h
+ *  This is an internal header file, included by other library headers.
+ *  You should not attempt to use it directly.
+ */
+
 #ifndef _CXXCONFIG
 #define _CXXCONFIG 1
 
@@ -38,7 +44,7 @@
 #include <bits/cpu_defines.h>
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20061024 
+#define __GLIBCXX__ 20070307 
 
 // Macros for visibility.
 # define _GLIBCXX_HAVE_ATTRIBUTE_VISIBILITY 1
@@ -193,6 +199,10 @@ _GLIBCXX_END_NAMESPACE
 // for something else under certain OSes (see BADNAMES).
 #define __N(msgid)     (msgid)
 
+// For example, <windows.h> is known to #define min and max as macros...
+#undef min
+#undef max
+
 // End of prewritten config; the discovered settings follow.
 /* config.h.  Generated by configure.  */
 /* config.h.in.  Generated from configure.ac by autoheader.  */
@@ -213,7 +223,7 @@ _GLIBCXX_END_NAMESPACE
 #define _GLIBCXX_HAVE_ATAN2F 1
 
 /* Define to 1 if you have the `atan2l' function. */
-/* #undef _GLIBCXX_HAVE_ATAN2L */
+#define _GLIBCXX_HAVE_ATAN2L 1
 
 /* Define to 1 if you have the `atanf' function. */
 #define _GLIBCXX_HAVE_ATANF 1
@@ -228,7 +238,7 @@ _GLIBCXX_END_NAMESPACE
 /* #undef _GLIBCXX_HAVE_CEILL */
 
 /* Define to 1 if you have the <complex.h> header file. */
-/* #undef _GLIBCXX_HAVE_COMPLEX_H */
+#define _GLIBCXX_HAVE_COMPLEX_H 1
 
 /* Define to 1 if you have the `copysign' function. */
 #define _GLIBCXX_HAVE_COPYSIGN 1
@@ -237,7 +247,7 @@ _GLIBCXX_END_NAMESPACE
 #define _GLIBCXX_HAVE_COPYSIGNF 1
 
 /* Define to 1 if you have the `copysignl' function. */
-/* #undef _GLIBCXX_HAVE_COPYSIGNL */
+#define _GLIBCXX_HAVE_COPYSIGNL 1
 
 /* Define to 1 if you have the `cosf' function. */
 #define _GLIBCXX_HAVE_COSF 1
@@ -264,7 +274,7 @@ _GLIBCXX_END_NAMESPACE
 #define _GLIBCXX_HAVE_FABSF 1
 
 /* Define to 1 if you have the `fabsl' function. */
-/* #undef _GLIBCXX_HAVE_FABSL */
+#define _GLIBCXX_HAVE_FABSL 1
 
 /* Define to 1 if you have the <fenv.h> header file. */
 /* #undef _GLIBCXX_HAVE_FENV_H */
@@ -303,7 +313,7 @@ _GLIBCXX_END_NAMESPACE
 #define _GLIBCXX_HAVE_FREXPF 1
 
 /* Define to 1 if you have the `frexpl' function. */
-/* #undef _GLIBCXX_HAVE_FREXPL */
+#define _GLIBCXX_HAVE_FREXPL 1
 
 /* Define to 1 if you have the <gconv.h> header file. */
 /* #undef _GLIBCXX_HAVE_GCONV_H */
@@ -373,7 +383,7 @@ _GLIBCXX_END_NAMESPACE
 #define _GLIBCXX_HAVE_LDEXPF 1
 
 /* Define to 1 if you have the `ldexpl' function. */
-/* #undef _GLIBCXX_HAVE_LDEXPL */
+#define _GLIBCXX_HAVE_LDEXPL 1
 
 /* Define to 1 if you have the <libintl.h> header file. */
 /* #undef _GLIBCXX_HAVE_LIBINTL_H */
@@ -484,7 +494,7 @@ _GLIBCXX_END_NAMESPACE
 #define _GLIBCXX_HAVE_SQRTF 1
 
 /* Define to 1 if you have the `sqrtl' function. */
-/* #undef _GLIBCXX_HAVE_SQRTL */
+#define _GLIBCXX_HAVE_SQRTL 1
 
 /* Define to 1 if you have the <stdbool.h> header file. */
 #define _GLIBCXX_HAVE_STDBOOL_H 1
@@ -502,10 +512,10 @@ _GLIBCXX_END_NAMESPACE
 #define _GLIBCXX_HAVE_STRING_H 1
 
 /* Define to 1 if you have the `strtof' function. */
-/* #undef _GLIBCXX_HAVE_STRTOF */
+#define _GLIBCXX_HAVE_STRTOF 1
 
 /* Define to 1 if you have the `strtold' function. */
-/* #undef _GLIBCXX_HAVE_STRTOLD */
+#define _GLIBCXX_HAVE_STRTOLD 1
 
 /* Define to 1 if you have the <sys/filio.h> header file. */
 #define _GLIBCXX_HAVE_SYS_FILIO_H 1
@@ -580,7 +590,7 @@ _GLIBCXX_END_NAMESPACE
 #define _GLIBCXX_HAVE_WCHAR_H 1
 
 /* Defined if wcstof exists. */
-/* #undef _GLIBCXX_HAVE_WCSTOF */
+#define _GLIBCXX_HAVE_WCSTOF 1
 
 /* Define to 1 if you have the <wctype.h> header file. */
 #define _GLIBCXX_HAVE_WCTYPE_H 1
@@ -823,13 +833,13 @@ _GLIBCXX_END_NAMESPACE
 #define _GLIBCXX_HAVE___BUILTIN_SQRTL 1
 
 /* Define to 1 if you have the `__signbit' function. */
-/* #undef _GLIBCXX_HAVE___SIGNBIT */
+#define _GLIBCXX_HAVE___SIGNBIT 1
 
 /* Define to 1 if you have the `__signbitf' function. */
-/* #undef _GLIBCXX_HAVE___SIGNBITF */
+#define _GLIBCXX_HAVE___SIGNBITF 1
 
 /* Define to 1 if you have the `__signbitl' function. */
-/* #undef _GLIBCXX_HAVE___SIGNBITL */
+#define _GLIBCXX_HAVE___SIGNBITL 1
 
 /* Name of package */
 /* #undef _GLIBCXX_PACKAGE */
@@ -879,7 +889,7 @@ _GLIBCXX_END_NAMESPACE
 /* #undef _GLIBCXX_SIZE_T_IS_UINT */
 
 /* Define if the compiler is configured for setjmp/longjmp exceptions. */
-/* #undef _GLIBCXX_SJLJ_EXCEPTIONS */
+#define _GLIBCXX_SJLJ_EXCEPTIONS 1
 
 /* Define to use symbol versioning in the shared library. */
 /* #undef _GLIBCXX_SYMVER */
@@ -921,7 +931,7 @@ _GLIBCXX_END_NAMESPACE
 
 /* Define if C99 functions or macros in <math.h> should be imported in <cmath>
    in namespace std. */
-/* #undef _GLIBCXX_USE_C99_MATH */
+#define _GLIBCXX_USE_C99_MATH 1
 
 /* Define if C99 functions or macros in <math.h> should be imported in
    <tr1/cmath> in namespace std::tr1. */
