@@ -1,6 +1,7 @@
 // Predefined symbols and macros -*- C++ -*-
 
-// Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+// Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
+// 2006, 2007
 // Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
@@ -28,6 +29,11 @@
 // invalidate any other reasons why the executable file might be covered by
 // the GNU General Public License.
 
+/** @file c++config.h
+ *  This is an internal header file, included by other library headers.
+ *  You should not attempt to use it directly.
+ */
+
 #ifndef _CXXCONFIG
 #define _CXXCONFIG 1
 
@@ -38,7 +44,7 @@
 #include <bits/cpu_defines.h>
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20061024 
+#define __GLIBCXX__ 20070307 
 
 // Macros for visibility.
 # define _GLIBCXX_HAVE_ATTRIBUTE_VISIBILITY 1
@@ -193,6 +199,10 @@ _GLIBCXX_END_NAMESPACE
 // for something else under certain OSes (see BADNAMES).
 #define __N(msgid)     (msgid)
 
+// For example, <windows.h> is known to #define min and max as macros...
+#undef min
+#undef max
+
 // End of prewritten config; the discovered settings follow.
 /* config.h.  Generated by configure.  */
 /* config.h.in.  Generated from configure.ac by autoheader.  */
@@ -346,7 +356,7 @@ _GLIBCXX_END_NAMESPACE
 #define _GLIBCXX_HAVE_INTTYPES_H 1
 
 /* Define to 1 if you have the `isinf' function. */
-#define _GLIBCXX_HAVE_ISINF 1
+/* #undef _GLIBCXX_HAVE_ISINF */
 
 /* Define to 1 if you have the `isinff' function. */
 #define _GLIBCXX_HAVE_ISINFF 1
@@ -355,7 +365,7 @@ _GLIBCXX_END_NAMESPACE
 /* #undef _GLIBCXX_HAVE_ISINFL */
 
 /* Define to 1 if you have the `isnan' function. */
-#define _GLIBCXX_HAVE_ISNAN 1
+/* #undef _GLIBCXX_HAVE_ISNAN */
 
 /* Define to 1 if you have the `isnanf' function. */
 #define _GLIBCXX_HAVE_ISNANF 1
@@ -502,7 +512,7 @@ _GLIBCXX_END_NAMESPACE
 #define _GLIBCXX_HAVE_STRING_H 1
 
 /* Define to 1 if you have the `strtof' function. */
-/* #undef _GLIBCXX_HAVE_STRTOF */
+#define _GLIBCXX_HAVE_STRTOF 1
 
 /* Define to 1 if you have the `strtold' function. */
 /* #undef _GLIBCXX_HAVE_STRTOLD */
@@ -823,10 +833,10 @@ _GLIBCXX_END_NAMESPACE
 #define _GLIBCXX_HAVE___BUILTIN_SQRTL 1
 
 /* Define to 1 if you have the `__signbit' function. */
-/* #undef _GLIBCXX_HAVE___SIGNBIT */
+#define _GLIBCXX_HAVE___SIGNBIT 1
 
 /* Define to 1 if you have the `__signbitf' function. */
-/* #undef _GLIBCXX_HAVE___SIGNBITF */
+#define _GLIBCXX_HAVE___SIGNBITF 1
 
 /* Define to 1 if you have the `__signbitl' function. */
 /* #undef _GLIBCXX_HAVE___SIGNBITL */
@@ -921,7 +931,7 @@ _GLIBCXX_END_NAMESPACE
 
 /* Define if C99 functions or macros in <math.h> should be imported in <cmath>
    in namespace std. */
-/* #undef _GLIBCXX_USE_C99_MATH */
+#define _GLIBCXX_USE_C99_MATH 1
 
 /* Define if C99 functions or macros in <math.h> should be imported in
    <tr1/cmath> in namespace std::tr1. */
